==> hugo_0.56.3.orig.tar.gz: hugo-0.56.3/docs/content/en/commands/hugo.md <==
---
date: 2019-07-31
title: "hugo"
slug: hugo
url: /commands/hugo/
---
## hugo

hugo builds your site

### Synopsis

hugo is the main command, used to build your Hugo site.

Hugo is a Fast and Flexible Static Site Generator
built with love by spf13 and friends in Go.

Complete documentation is available at http://gohugo.io/.

```
hugo [flags]
```

### Options

```
  -b, --baseURL string         hostname (and path) to the root, e.g. http://spf13.com/
  -D, --buildDrafts            include content marked as draft
  -E, --buildExpired           include expired content
  -F, --buildFuture            include content with publishdate in the future
      --cacheDir string        filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --cleanDestinationDir    remove files from destination not found in static directories
      --config string          config file (default is path/config.yaml|json|toml)
      --configDir string       config dir (default "config")
  -c, --contentDir string      filesystem path to content directory
      --debug                  debug output
  -d, --destination string     filesystem path to write files to
      --disableKinds strings   disable different kind of pages (home, RSS etc.)
      --enableGitInfo          add Git revision, date and author info to the pages
  -e, --environment string     build environment
      --forceSyncStatic        copy all files when static is changed.
      --gc                     enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                   help for hugo
      --i18n-warnings          print missing translations
      --ignoreCache            ignores the cache directory
      --ignoreVendor           ignores any _vendor directory
  -l, --layoutDir string       filesystem path to layout directory
      --log                    enable Logging
      --logFile string         log File path (if set, logging enabled automatically)
      --minify                 minify any supported output format (HTML, XML etc.)
      --noChmod                don't sync permission mode of files
      --noTimes                don't sync modification time of files
      --path-warnings          print warnings on duplicate target paths etc.
      --quiet                  build in quiet mode
      --renderToMemory         render to memory (only useful for benchmark testing)
  -s, --source string          filesystem path to read files relative from
      --templateMetrics        display metrics about template executions
      --templateMetricsHints   calculate some improvement hints when combined with --templateMetrics
  -t, --theme strings          themes to use (located in /themes/THEMENAME/)
      --themesDir string       filesystem path to themes directory
      --trace file             write trace to file (not useful in general)
  -v, --verbose                verbose output
      --verboseLog             verbose logging
  -w, --watch                  watch filesystem for changes and recreate as needed
```

### SEE ALSO

* [hugo check](/commands/hugo_check/)	 - Contains some verification checks
* [hugo config](/commands/hugo_config/)	 - Print the site configuration
* [hugo convert](/commands/hugo_convert/)	 - Convert your content to different formats
* [hugo deploy](/commands/hugo_deploy/)	 - Deploy your site to a Cloud provider.
* [hugo env](/commands/hugo_env/)	 - Print Hugo version and environment info
* [hugo gen](/commands/hugo_gen/)	 - A collection of several useful generators.
* [hugo import](/commands/hugo_import/)	 - Import your site from others.
* [hugo list](/commands/hugo_list/)	 - Listing out various types of content
* [hugo mod](/commands/hugo_mod/)	 - Various Hugo Modules helpers.
* [hugo new](/commands/hugo_new/)	 - Create new content for your site
* [hugo server](/commands/hugo_server/)	 - A high performance webserver
* [hugo version](/commands/hugo_version/)	 - Print the version number of Hugo

###### Auto generated by spf13/cobra on 31-Jul-2019

==> hugo_0.68.3.orig.tar.gz: hugo-0.68.3/docs/content/en/commands/hugo.md <==
---
date: 2020-03-03
title: "hugo"
slug: hugo
url: /commands/hugo/
---
## hugo

hugo builds your site

### Synopsis

hugo is the main command, used to build your Hugo site.

Hugo is a Fast and Flexible Static Site Generator
built with love by spf13 and friends in Go.

Complete documentation is available at http://gohugo.io/.

```
hugo [flags]
```

### Options

```
  -b, --baseURL string         hostname (and path) to the root, e.g. http://spf13.com/
  -D, --buildDrafts            include content marked as draft
  -E, --buildExpired           include expired content
  -F, --buildFuture            include content with publishdate in the future
      --cacheDir string        filesystem path to cache directory. Defaults: $TMPDIR/hugo_cache/
      --cleanDestinationDir    remove files from destination not found in static directories
      --config string          config file (default is path/config.yaml|json|toml)
      --configDir string       config dir (default "config")
  -c, --contentDir string      filesystem path to content directory
      --debug                  debug output
  -d, --destination string     filesystem path to write files to
      --disableKinds strings   disable different kind of pages (home, RSS etc.)
      --enableGitInfo          add Git revision, date and author info to the pages
  -e, --environment string     build environment
      --forceSyncStatic        copy all files when static is changed.
      --gc                     enable to run some cleanup tasks (remove unused cache files) after the build
  -h, --help                   help for hugo
      --i18n-warnings          print missing translations
      --ignoreCache            ignores the cache directory
      --ignoreVendor           ignores any _vendor directory
  -l, --layoutDir string       filesystem path to layout directory
      --log                    enable Logging
      --logFile string         log File path (if set, logging enabled automatically)
      --minify                 minify any supported output format (HTML, XML etc.)
      --noChmod                don't sync permission mode of files
      --noTimes                don't sync modification time of files
      --path-warnings          print warnings on duplicate target paths etc.
      --quiet                  build in quiet mode
      --renderToMemory         render to memory (only useful for benchmark testing)
  -s, --source string          filesystem path to read files relative from
      --templateMetrics        display metrics about template executions
      --templateMetricsHints   calculate some improvement hints when combined with --templateMetrics
  -t, --theme strings          themes to use (located in /themes/THEMENAME/)
      --themesDir string       filesystem path to themes directory
      --trace file             write trace to file (not useful in general)
  -v, --verbose                verbose output
      --verboseLog             verbose logging
  -w, --watch                  watch filesystem for changes and recreate as needed
```

### SEE ALSO

* [hugo check](/commands/hugo_check/)	 - Contains some verification checks
* [hugo config](/commands/hugo_config/)	 - Print the site configuration
* [hugo convert](/commands/hugo_convert/)	 - Convert your content to different formats
* [hugo deploy](/commands/hugo_deploy/)	 - Deploy your site to a Cloud provider.
* [hugo env](/commands/hugo_env/)	 - Print Hugo version and environment info
* [hugo gen](/commands/hugo_gen/)	 - A collection of several useful generators.
* [hugo import](/commands/hugo_import/)	 - Import your site from others.
* [hugo list](/commands/hugo_list/)	 - Listing out various types of content
* [hugo mod](/commands/hugo_mod/)	 - Various Hugo Modules helpers.
* [hugo new](/commands/hugo_new/)	 - Create new content for your site
* [hugo server](/commands/hugo_server/)	 - A high performance webserver
* [hugo version](/commands/hugo_version/)	 - Print the version number of Hugo

###### Auto generated by spf13/cobra on 3-Mar-2020
